# Copyright 1999-2022 Gentoo Authors
# Distributed under the terms of the GNU General Public License v2

EAPI=6

MULTILIB_COMPAT=( abi_x86_64 )

inherit pax-utils multilib-build xdg-utils desktop

DESCRIPTION="Microsoft franz for Linux is your chat-centered workspace in Office 365"
HOMEPAGE="https://aka.ms/microsoftfranz"
SRC_URI="https://github.com/meetfranz/franz/releases/download/v${PV}/${P}.tar.gz"

LICENSE="no-source-code MIT MIT-with-advertising BSD-1 BSD-2 BSD Apache-2.0 Boost-1.0 ISC CC-BY-SA-3.0 CC0-1.0 openssl ZLIB APSL-2 icu Artistic-2 LGPL-2.1"
SLOT="0"
KEYWORDS="~amd64"
IUSE="pax_kernel"

QA_PREBUILT=opt/Franz/franz
RESTRICT="mirror bindist strip" #299368

RDEPEND="
	app-crypt/libsecret[${MULTILIB_USEDEP}]
	dev-libs/atk[${MULTILIB_USEDEP}]
	dev-libs/expat[${MULTILIB_USEDEP}]
	dev-libs/glib:2[${MULTILIB_USEDEP}]
	dev-libs/nspr[${MULTILIB_USEDEP}]
	dev-libs/nss[${MULTILIB_USEDEP}]
	gnome-base/gconf:2[${MULTILIB_USEDEP}]
	media-libs/alsa-lib[${MULTILIB_USEDEP}]
	media-libs/fontconfig:1.0[${MULTILIB_USEDEP}]
	media-libs/freetype:2[${MULTILIB_USEDEP}]
	media-libs/libv4l[${MULTILIB_USEDEP}]
	net-print/cups[${MULTILIB_USEDEP}]
	sys-apps/dbus[${MULTILIB_USEDEP}]
	sys-devel/gcc[cxx]
	virtual/ttf-fonts
	x11-libs/cairo[${MULTILIB_USEDEP}]
	x11-libs/gdk-pixbuf:2[${MULTILIB_USEDEP}]
	x11-libs/gtk+:2[${MULTILIB_USEDEP}]
	x11-libs/libX11[${MULTILIB_USEDEP}]
	x11-libs/libXScrnSaver[${MULTILIB_USEDEP}]
	x11-libs/libXcomposite[${MULTILIB_USEDEP}]
	x11-libs/libXcursor[${MULTILIB_USEDEP}]
	x11-libs/libXdamage[${MULTILIB_USEDEP}]
	x11-libs/libXext[${MULTILIB_USEDEP}]
	x11-libs/libXfixes[${MULTILIB_USEDEP}]
	x11-libs/libXi[${MULTILIB_USEDEP}]
	x11-libs/libXrandr[${MULTILIB_USEDEP}]
	x11-libs/libXrender[${MULTILIB_USEDEP}]
	x11-libs/libXtst[${MULTILIB_USEDEP}]
	x11-libs/libxcb[${MULTILIB_USEDEP}]
	x11-libs/libxkbfile[${MULTILIB_USEDEP}]
	x11-libs/pango[${MULTILIB_USEDEP}]"

src_install() {
	insinto /opt/Franz/locales
	doins locales/*.pak

	insinto /opt/Franz/resources/app.asar.unpacked/assets/images/taskbar/win32
	doins resources/app.asar.unpacked/assets/images/taskbar/win32/*.ico

	insinto /opt/Franz/resources/app.asar.unpacked/dictionaries
	doins -r resources/app.asar.unpacked/dictionaries/*

	insinto /opt/Franz/resources
	doins resources/*.asar

	insinto /opt/Franz
	doins *.pak
	doins *.bin
	doins *.dat
	exeinto /opt/Franz
	doexe *.so
	doexe franz
	doexe chrome-sandbox

	exeinto /opt/Franz/swiftshader
	doexe swiftshader/*.so

	into /opt
	dobin "${FILESDIR}"/franz

	dodoc *.html
	dodoc *.txt
	#dodoc -r usr/share/doc/franz/.
	# symlink required for the "Help->3rd Party Notes" menu entry  (otherwise frozen skype -> xdg-open)
	#dosym ${P} usr/share/doc/franz

	# compat symlink for franz bin autocreate autostart desktop file
	dosym ../../opt/bin/franz usr/bin/franz

	domenu "${FILESDIR}"/franz.desktop
	doicon "${FILESDIR}"/franz.svg

	if use pax_kernel; then
		pax-mark -Cm "${ED%/}"/opt/Franz/franz
		eqawarn "You have set USE=pax_kernel meaning that you intend to run"
		eqawarn "${PN} under a PaX enabled kernel. To do so, we must modify"
		eqawarn "the ${PN} binary itself and this *may* lead to breakage! If"
		eqawarn "you suspect that ${PN} is being broken by this modification,"
		eqawarn "please open a bug."
	fi
}

pkg_postinst() {
	xdg_desktop_database_update
	xdg_mimeinfo_database_update
}

pkg_postrm() {
	xdg_desktop_database_update
	xdg_mimeinfo_database_update
}
