# Copyright 1999-2022 Gentoo Authors
# Distributed under the terms of the GNU General Public License v2

EAPI=6

inherit pax-utils xdg-utils versionator desktop

PV_MAJ=$(get_major_version )
PV_MIN=$(get_version_component_range 2)
PV_SUB=$(get_version_component_range 3)
PV_DIF=$(get_version_component_range 4)
MY_PV="${PV_MAJ}.${PV_MIN}.${PV_DIF}"

DESCRIPTION="Parallels Remote Application Client"
HOMEPAGE="https://www.parallels.com/eu/products/ras/download/links/#lin"
SRC_URI="amd64? ( http://download.parallels.com/ras/v${PV_MAJ}/${PV}/RASClient-${MY_PV}_x86_64.tar.bz2
		http://download.parallels.com/ras/v${PV_MAJ}/${PV}/RASClient-sso-${MY_PV}_x86_64.tar.bz2 )"

LICENSE="no-source-code"
SLOT="0"
KEYWORDS="~amd64"
IUSE=""

S="${WORKDIR}"
RESTRICT="mirror bindist strip" #299368

DEPEND="dev-libs/libxml2
	dev-qt/qtcore:5
	dev-qt/qtdbus:5
	dev-qt/qtgui:5
	dev-qt/qtnetwork:5
	dev-qt/qtprintsupport:5
	dev-qt/qtwidgets:5
	dev-qt/qtx11extras:5
	dev-qt/qtxml:5
	media-libs/alsa-lib
	net-print/cups
	sys-libs/zlib
	x11-libs/libX11
	x11-libs/libXext
	x11-libs/libXinerama
	x11-libs/libXrandr
	x11-libs/libXtst
	virtual/libusb:1
	sys-apps/pcsc-lite
	sys-libs/glibc
	x11-libs/libXpm
	"

RDEPEND="${DEPEND}"

src_install() {
	into /opt/2X/Client/
	dobin opt/2X/Client/bin/*
	dolib.so opt/2X/Client/lib/*
	ln -sf $(get_libdir) "${D}/opt/2X/Client/lib"

	dodoc opt/2X/Client/doc/*

	doicon opt/2X/Client/share/2X.png

	domenu opt/2X/Client/share/rasclient.desktop
	domenu opt/2X/Client/share/tuxclient.desktop
	domenu opt/2X/Client/share/rassession.desktop

	insinto /usr/share/mime-info
	doins opt/2X/Client/share/mime/*.{keys,mime}

	insinto /usr/share/application-registry
	doins opt/2X/Client/share/mime/2XSession.applications

	insinto /usr/share/mime/packages/
	doins opt/2X/Client/share/sharedmimeinfo/2XClient.xml

	insinto /opt/2X/Client/share
	doins opt/2X/Client/share/*.{conf,qm,qss,pem}
	doins opt/2X/Client/share/installed
}

pkg_postinst() {
	xdg_desktop_database_update
	xdg_mimeinfo_database_update
}

pkg_postrm() {
	xdg_desktop_database_update
	xdg_mimeinfo_database_update
}
